# Revision History

## 1.0.3 (6 September 2018)

- parameter encoding

## 1.0.2 (30 October 2017)

 - Corrected the validation of IPv4 and IPv6 IP addresses
 - Added an optional parameter to specify TLS 1.1 or 1.2 on the initialization of EmailageClient
